@@ -15,7 +15,14 @@ goto() {
 
     if [ "$?" = "0" ]; then
         DIR=$(head -1 /tmp/goto)
-        goto_dir $DIR
+
+        if [ "$DIR" == "<PATH>" ]; then
+            DIR=$(sed -n '2p' /tmp/goto)
+            goto_dir "$DIR"
+        else
+            cat /tmp/goto
+        fi
+
     else
         cat /tmp/goto
     fi
